Oncilla - 0.1.0 - Alpha
=======================

.. .changes

Changes
=======


0.1.0 - Alpha
-------------

-  Initial release of **Oncilla**.

.. .about

About
-----

| **Oncilla** by Thomas Mansencal – 2008 - 2014
| Copyright© 2008 - 2014 – Thomas Mansencal – `thomas.mansencal@gmail.com <mailto:thomas.mansencal@gmail.com>`_
| This software is released under terms of GNU GPL V3 license: http://www.gnu.org/licenses/
| `http://www.thomasmansencal.com/ <http://www.thomasmansencal.com/>`_